aboutsummaryrefslogtreecommitdiffstats
path: root/eth/protocol.go
diff options
context:
space:
mode:
Diffstat (limited to 'eth/protocol.go')
-rw-r--r--eth/protocol.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/eth/protocol.go b/eth/protocol.go
index 328d5b993..bee3d8365 100644
--- a/eth/protocol.go
+++ b/eth/protocol.go
@@ -104,8 +104,8 @@ type txPool interface {
Pending() (map[common.Address]types.Transactions, error)
// SubscribeTxPreEvent should return an event subscription of
- // TxPreEvent and send events to the given channel.
- SubscribeTxPreEvent(chan<- core.TxPreEvent) event.Subscription
+ // TxsPreEvent and send events to the given channel.
+ SubscribeTxPreEvent(chan<- core.TxsPreEvent) event.Subscription
}
// statusData is the network packet for the status message.